#!/usr/bin/env python

# Base on Conbagui tutorial found here:
# https://www.facebook.com/groups/TheGIMP/permalink/2730192950634617/?comment_id=2730331093954136&reply_comment_id=2731019563885289

# 
# author: Pocholo
# date: 9/26/2020

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugins folder


# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY# without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>. 


from gimpfu import *

def pm_inward_rep_effect(img, draw):

	
	
	width = 1600
	height = 1000
		
	#Re-name the background
	pdb.gimp_item_set_name(draw, "Background")
	
	#Crop image
	pdb.gimp_image_crop(img, 1600, 1000, 0, 0)
	
	#Place vertical guides
	guide = pdb.gimp_image_add_vguide(img, 1200)
	guide = pdb.gimp_image_add_vguide(img, 800)
	guide = pdb.gimp_image_add_vguide(img, 400)
	
	#Use ofnut guillotine script
	pdb.python_fu_ofn_guillotine_layer(img, draw)
	
	#Remove vertical guides
	pdb.script_fu_guides_remove(img, draw)
	

	#Reverse layer stack and place background layer in place
	pdb.script_fu_reverse_layers(img, draw)
	pdb.gimp_image_lower_item_to_bottom(img, draw)
	
	#Re-name all layers
	layerA = pdb.gimp_image_get_layer_by_name(img, "Background @ (0,0)")
	pdb.gimp_item_set_name(layerA, "A")
	layerB = pdb.gimp_image_get_layer_by_name(img, "Background @ (400,0)")
	pdb.gimp_item_set_name(layerB, "B")
	layerC = pdb.gimp_image_get_layer_by_name(img, "Background @ (800,0)")
	pdb.gimp_item_set_name(layerC, "C")
	layerD = pdb.gimp_image_get_layer_by_name(img, "Background @ (1200,0)")
	pdb.gimp_item_set_name(layerD, "D")
	
	pdb.gimp_item_set_visible(draw, TRUE)
	
	#Create perspective effect
	layerA = pdb.gimp_item_transform_perspective(layerA, 0, 250, 400, 0, 0, 750, 400, 1000)
	layerB = pdb.gimp_item_transform_perspective(layerB, 400, 250, 800, 0, 400, 750, 800, 1000)
	layerC = pdb.gimp_item_transform_perspective(layerC, 800, 250, 1200, 0, 800, 750, 1200, 1000)
	layerD = pdb.gimp_item_transform_perspective(layerD, 1200, 250, 1600, 0, 1200, 750, 1600, 1000)
	
	 
	#Make duplicates
	non_empty = pdb.gimp_edit_copy(layerA)
	layerAA = pdb.gimp_layer_new(img, width, height, RGB, "AA", 100, LAYER_MODE_SCREEN)
	pdb.gimp_image_add_layer(img, layerAA, 4)
	pdb.gimp_layer_add_alpha(layerAA)
	pdb.gimp_drawable_fill(layerAA, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(layerAA, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	non_empty = pdb.gimp_edit_copy(layerB)
	layerBB = pdb.gimp_layer_new(img, width, height, RGB, "BB", 100, LAYER_MODE_SCREEN)
	pdb.gimp_image_add_layer(img, layerBB, 5)
	pdb.gimp_layer_add_alpha(layerBB)
	pdb.gimp_drawable_fill(layerBB, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(layerBB, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	non_empty = pdb.gimp_edit_copy(layerC)
	layerCC = pdb.gimp_layer_new(img, width, height, RGB, "CC", 100, LAYER_MODE_SCREEN)
	pdb.gimp_image_add_layer(img, layerCC, 6)
	pdb.gimp_layer_add_alpha(layerCC)
	pdb.gimp_drawable_fill(layerCC, FILL_TRANSPARENT)
	floating_sel = pdb.gimp_edit_paste(layerCC, FALSE)
	pdb.gimp_floating_sel_anchor(floating_sel)
	
	#Flip images
	layerAA = pdb.gimp_item_transform_flip_simple(layerAA, ORIENTATION_HORIZONTAL, TRUE, 0)
	pdb.gimp_layer_translate(layerAA, -205, 0)
	pdb.gimp_layer_resize_to_image_size(layerAA)
	layerBB = pdb.gimp_item_transform_flip_simple(layerBB, ORIENTATION_HORIZONTAL, TRUE, 0)
	pdb.gimp_layer_translate(layerBB, 195, 0)
	pdb.gimp_layer_resize_to_image_size(layerBB)
	layerCC = pdb.gimp_item_transform_flip_simple(layerCC, ORIENTATION_HORIZONTAL, TRUE, 0)
	pdb.gimp_layer_translate(layerCC, 598, 0)
	pdb.gimp_layer_resize_to_image_size(layerCC)
	
	#Make a new from visible and rename the layer	
	pdb.gimp_image_set_active_layer(img, draw)
	effect = pdb.gimp_layer_new_from_visible(img, img, "Inward Rep Effect")
	pdb.gimp_image_add_layer(img, effect, 7)
	
	
	pdb.gimp_image_remove_layer(img, draw)
	
	#Make invisible
	pdb.gimp_item_set_visible(layerA, FALSE)
	pdb.gimp_item_set_visible(layerB, FALSE)
	pdb.gimp_item_set_visible(layerC, FALSE)
	pdb.gimp_item_set_visible(layerD, FALSE)
	pdb.gimp_item_set_visible(layerAA, FALSE)
	pdb.gimp_item_set_visible(layerBB, FALSE)
	pdb.gimp_item_set_visible(layerCC, FALSE)
	
	#Apply g'mic
	pdb.plug_in_gmic_qt(img, effect, 1, 0, "-v - -fx_frame_blur 30,30,0,5,0,0,128,128,128,0,5,255,255,255,2,2,1,0,0.5,0.5,0")
	
register(
	"pm_inward_rep_effect",
	"Creates an inward repetition",
	"Creates an image inward repetition",
	"Pocholo",
	"Pocholo",
	"2020",
	"Inward Rep Effect",
	"",
[
	(PF_IMAGE, "img", "Image", None),
	(PF_DRAWABLE, "draw", "Drawable", None),
],
[],
pm_inward_rep_effect, menu="<Image>/Pocholo-scripts/Inward Rep Effect")
main()							